"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
class Hooks {
    constructor() {
        this._hooks = {
            before: [],
            after: [],
        };
    }
    before(cb) {
        this._hooks.before.push(cb);
        return this;
    }
    after(cb) {
        this._hooks.after.push(cb);
        return this;
    }
    async executeBefore(ctx) {
        const action = ctx.profiler.profile('http:before:hooks');
        try {
            for (let hook of this._hooks.before) {
                await hook(ctx);
                if (ctx.response.hasLazyBody || !ctx.response.isPending) {
                    action.end();
                    return true;
                }
            }
            action.end();
            return false;
        }
        catch (error) {
            action.end();
            throw error;
        }
    }
    async executeAfter(ctx) {
        const action = ctx.profiler.profile('http:after:hooks');
        try {
            for (let hook of this._hooks.after) {
                await hook(ctx);
            }
            action.end();
        }
        catch (error) {
            action.end();
            throw error;
        }
    }
    commit() {
        if (this._hooks.before.length === 0) {
            this.executeBefore = async () => false;
        }
        if (this._hooks.after.length === 0) {
            this.executeAfter = async () => { };
        }
    }
}
exports.Hooks = Hooks;
